@@ -11,9 +11,9 @@ trellis.device(postscript, file="ch04.ps", width=8, height=6,
 options(echo=T, width=65, digits=5)
 
 
-# 3.2  Basic plotting functions
+# 4.2  Basic plotting functions
 
-data(mdeaths); data(fdeaths); library(ts)
+library(ts)
 lung.deaths <- aggregate(ts.union(mdeaths, fdeaths), 1)
 barplot(t(lung.deaths), names = dimnames(lung.deaths)[[1]],
         main = "UK deaths from lung disease")
@@ -27,7 +27,6 @@ text(loc, total + par("cxy")[2], total, cex = 0.7, xpd = T)
 # S: if(interactive()) brush(hills)
 
 library(modreg)
-data(topo)
 topo.loess <- loess(z ~ x * y, topo, degree = 2, span = 0.25)
 topo.mar <- list(x = seq(0, 6.5, 0.2), y=seq(0, 6.5, 0.2))
 topo.lo <- predict(topo.loess, expand.grid(topo.mar))
@@ -37,23 +36,22 @@ contour(topo.mar$x, topo.mar$y, topo.lo, xlab = "", ylab = "",
   levels = seq(700,1000,25), cex = 0.7)
 points(topo$x, topo$y)
 par(pty =  "m")
-if(F) { # not currently operational
-contourplot(z ~ x * y, mat2tr(topo.lo), aspect = 1,
+topo.lo1 <- cbind(expand.grid(x=topo.mar$x, y=topo.mar$y),
+                  z=as.vector(topo.lo))
+contourplot(z ~ x * y, topo.lo1, aspect = 1,
   at = seq(700, 1000, 25), xlab = "", ylab = "",
   panel = function(x, y, subscripts, ...) {
-     panel.contourplot(x, y, subscripts, ...)
+     panel.levelplot(x, y, subscripts, ...)
      panel.xyplot(topo$x,topo$y, cex = 0.5)
   }
 )
-}
 
 # see help(Skye)
 # ternary(Skye/100, ord = c(1, 3, 2))
 
 
-# 3.3  Enhancing plots
+# 4.3  Enhancing plots
 
-data(wtloss)
 attach(wtloss)
 oldpar <- par(no.readonly = TRUE)
 # alter margin 4; others are default
@@ -76,7 +74,7 @@ plot(lambda, sapply(lambda, plik), type = "l", ylim = c(0, 1.4),
 abline(h = 1, lty = 3)
 
 
-# 3.4  Fine control of graphics
+# 4.4  Fine control of graphics
 
 ## in R just use data(swiss)
 # swiss <- data.frame(Fertility = swiss.fertility, swiss.x)
@@ -116,10 +114,9 @@ mtext(expression(R[i]), side = 2, line = 2, at = yul[2])
 detach()
 
 
-# 3.5  Trellis graphics
+# 4.5  Trellis graphics
 
 
-data(hills)
 library(lqs)
 xyplot(time ~ dist, data = hills,
   panel = function(x, y, ...) {
@@ -130,7 +127,6 @@ xyplot(time ~ dist, data = hills,
   }
 )
 
-data(michelson)
 bwplot(Expt ~ Speed, data = michelson, ylab = "Experiment No.")
 title("Speed of Light Data")
 
@@ -141,7 +137,6 @@ splom(~ swiss, aspect = "fill",
   }
 )
 
-data(stormer)
 sps <- trellis.par.get("superpose.symbol")
 sps$pch <- 1:7
 trellis.par.set("superpose.symbol", sps)
@@ -170,7 +165,6 @@ wireframe(pred ~ x * y, topo.plt, aspect = c(1, 0.5),
   colorkey = list(space="right", height=0.6))
 }
 
-data(crabs)
 library(mva)
 lcrabs.pc <- predict(princomp(log(crabs[,4:8])))
 crabs.grp <- c("B", "b", "O", "o")[rep(1:4, each = 50)]
@@ -188,7 +182,6 @@ sp <- crabs$sp
 levels(sp) <- c("Blue", "Orange")
 splom(~ lcrabs.pc[, 1:3] | sp*sex, cex = 0.5, pscales = 0)
 
-data(quine)
 Quine <- quine
 levels(Quine$Eth) <- c("Aboriginal", "Non-aboriginal")
 levels(Quine$Sex) <- c("Female", "Male")
@@ -206,7 +199,7 @@ stripplot(Age ~ Days | Sex*Lrn*Eth, data = Quine,
 stripplot(Age ~ Days | Eth*Sex, data = Quine,
    groups = Lrn, jitter = T,
    panel = function(x, y, subscripts, jitter.data = F, ...) {
-       if(jitter.data)  y <- jitter(y)
+       if(jitter.data)  y <- jitter(as.numeric(y))
        panel.superpose(x, y, subscripts, ...)
    },
    xlab = "Days of absence",
@@ -218,7 +211,6 @@ stripplot(Age ~ Days | Eth*Sex, data = Quine,
         strip.default(..., strip.names = c(T, T), style = 1)
 )
 
-data(fgl)
 fgl0 <- fgl[ ,-10] # omit type.
 fgl.df <- data.frame(type = rep(fgl$type, 9),
   y = as.vector(as.matrix(fgl0)),
